From 017bcefb3f746b56cb66e898b8c178c1e8e5ce60 Mon Sep 17 00:00:00 2001
From: Goutham Veeramachaneni <gouthamve@gmail.com>
Date: Mon, 6 May 2019 10:45:18 +0530
Subject: [PATCH] Better buckets for chunk sizes (#529)

Signed-off-by: Goutham Veeramachaneni <gouthamve@gmail.com>
---
 pkg/ingester/flush.go | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/pkg/ingester/flush.go b/pkg/ingester/flush.go
index b00d4064..7bdeae54 100644
--- a/pkg/ingester/flush.go
+++ b/pkg/ingester/flush.go
@@ -23,12 +23,12 @@ var (
 	chunkEntries = promauto.NewHistogram(prometheus.HistogramOpts{
 		Name:    "loki_ingester_chunk_entries",
 		Help:    "Distribution of stored chunk entries (when stored).",
-		Buckets: prometheus.ExponentialBuckets(20, 2, 11), // biggest bucket is 5*2^(11-1) = 5120
+		Buckets: prometheus.ExponentialBuckets(200, 2, 9), // biggest bucket is 200*2^(9-1) = 51200
 	})
 	chunkSize = promauto.NewHistogram(prometheus.HistogramOpts{
 		Name:    "loki_ingester_chunk_size_bytes",
 		Help:    "Distribution of stored chunk sizes (when stored).",
-		Buckets: prometheus.ExponentialBuckets(500, 2, 5), // biggest bucket is 500*2^(5-1) = 8000
+		Buckets: prometheus.ExponentialBuckets(10000, 2, 7), // biggest bucket is 10000*2^(7-1) = 640000 (~640KB)
 	})
 	chunksPerTenant = promauto.NewCounterVec(prometheus.CounterOpts{
 		Name: "loki_ingester_chunks_stored_total",
-- 
GitLab